==> ruta-3.1.0-source-release.zip: ruta-3.1.0/ruta-core/src/test/java/org/apache/uima/ruta/condition/AfterTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.ruta.condition;

import org.apache.uima.cas.CAS;
import org.apache.uima.ruta.engine.Ruta;
import org.apache.uima.ruta.engine.RutaTestUtils;
import org.junit.Test;

public class AfterTest {

  @Test
  public void test() {

    CAS cas = RutaTestUtils.processTestScript(this.getClass());

    RutaTestUtils.assertAnnotationsEquals(cas, 1, 2, ".", ".");
    RutaTestUtils.assertAnnotationsEquals(cas, 2, 8, "So", "every", "word", "from", "here", "on",
            "is", "marked");
    RutaTestUtils.assertAnnotationsEquals(cas, 3, 9, "dot", "So", "every", "word", "from", "here",
            "on", "is", "marked");
    RutaTestUtils.assertAnnotationsEquals(cas, 4, 9, "dot", "So", "every", "word", "from", "here",
            "on", "is", "marked");

  }

  @Test
  public void testInWindow() throws Exception {
    String document = "x x . A b 1 . x x";
    String script = "";
    script += "PERIOD #{-> T1} PERIOD;";
    script += "T1->{NUM{AFTER(CW)-> T2};};";
    script += "T1->{NUM{AFTER(PERIOD)-> T3};};";
    script += "T1->{SW{AFTER(CW)-> T4};};";
    script += "T1->{SW{AFTER(SW)-> T5};};";
    script += "T1->{CW{AFTER(PERIOD)-> T6};};";
    script += "T1->{CW{AFTER(CW)-> T7};};";

    CAS cas = RutaTestUtils.getCAS(document);
    Ruta.apply(cas, script);

    RutaTestUtils.assertAnnotationsEquals(cas, 2, 1, "1");
    RutaTestUtils.assertAnnotationsEquals(cas, 3, 0);
    RutaTestUtils.assertAnnotationsEquals(cas, 4, 1, "b");
    RutaTestUtils.assertAnnotationsEquals(cas, 5, 0);
    RutaTestUtils.assertAnnotationsEquals(cas, 6, 0);
    RutaTestUtils.assertAnnotationsEquals(cas, 7, 0);

  }
}

==> ruta-3.5.0-source-release.zip: ruta-3.5.0/ruta-core/src/test/java/org/apache/uima/ruta/condition/AfterTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.uima.ruta.condition;

import org.apache.uima.cas.CAS;
import org.apache.uima.ruta.engine.Ruta;
import org.apache.uima.ruta.engine.RutaTestUtils;
import org.junit.jupiter.api.Test;

public class AfterTest {

  @Test
  public void test() {

    CAS cas = RutaTestUtils.processTestScript(this.getClass());

    RutaTestUtils.assertAnnotationsEquals(cas, 1, 2, ".", ".");
    RutaTestUtils.assertAnnotationsEquals(cas, 2, 8, "So", "every", "word", "from", "here", "on",
            "is", "marked");
    RutaTestUtils.assertAnnotationsEquals(cas, 3, 9, "dot", "So", "every", "word", "from", "here",
            "on", "is", "marked");
    RutaTestUtils.assertAnnotationsEquals(cas, 4, 9, "dot", "So", "every", "word", "from", "here",
            "on", "is", "marked");

  }

  @Test
  public void testInWindow() throws Exception {
    String document = "x x . A b 1 . x x";
    String script = "";
    script += "PERIOD #{-> T1} PERIOD;";
    script += "T1->{NUM{AFTER(CW)-> T2};};";
    script += "T1->{NUM{AFTER(PERIOD)-> T3};};";
    script += "T1->{SW{AFTER(CW)-> T4};};";
    script += "T1->{SW{AFTER(SW)-> T5};};";
    script += "T1->{CW{AFTER(PERIOD)-> T6};};";
    script += "T1->{CW{AFTER(CW)-> T7};};";

    CAS cas = RutaTestUtils.getCAS(document);
    Ruta.apply(cas, script);

    RutaTestUtils.assertAnnotationsEquals(cas, 2, 1, "1");
    RutaTestUtils.assertAnnotationsEquals(cas, 3, 0);
    RutaTestUtils.assertAnnotationsEquals(cas, 4, 1, "b");
    RutaTestUtils.assertAnnotationsEquals(cas, 5, 0);
    RutaTestUtils.assertAnnotationsEquals(cas, 6, 0);
    RutaTestUtils.assertAnnotationsEquals(cas, 7, 0);

  }
}
